from __future__ import annotations

from time import sleep, time

import pytest

from acquire.volatilestream import timeout


def test_volatile_stream_timeout() -> None:
    def snooze() -> None:
        sleep(10)

    function = timeout(snooze, timelimit=5)
    start = time()

    with pytest.raises(TimeoutError):
        function()

    end = time()

    assert end - start < 6



from __future__ import annotations

from unittest.mock import patch

import pytest

from acquire.esxi import EsxiMemoryManager


def test_vsish_command() -> None:
    memory = EsxiMemoryManager()
    with patch("subprocess.check_output", return_value=b"hello"):
        assert memory._execute_vsish_command(["hello", "world"]) == "hello"


@pytest.mark.parametrize(
    ("command_output", "expected_result"),
    [(b"1", "1"), (b"1 2", "1")],
)
def test_process_number(command_output: bytes, expected_result: str) -> None:
    memory = EsxiMemoryManager()
    with patch("subprocess.check_output", return_value=command_output):
        assert memory._get_group_id() == expected_result


def test_process_number_empty() -> None:
    memory = EsxiMemoryManager()
    with (
        patch("subprocess.check_output", return_value=b""),
        pytest.raises(ValueError, match="Something went wrong, group_id was empty"),
    ):
        memory._get_group_id()


def test_get_scheme() -> None:
    memory = EsxiMemoryManager()
    with patch("subprocess.check_output", return_value=b"hello:10"):
        assert memory._get_memory_scheme() == {"hello": "10"}



from __future__ import annotations

from multiprocessing import Queue
from typing import TYPE_CHECKING

import pytest

from acquire.tools.decrypter import check_existing, find_enc_files

if TYPE_CHECKING:
    from pathlib import Path


def test_find_non_encrypted_files(tmp_path: Path) -> None:
    input_files = [tmp_path / "test", tmp_path / "help"]

    for file in input_files:
        file.touch()

    assert find_enc_files(input_files) == []


def test_find_inside_dir(tmp_path: Path) -> None:
    output_path = tmp_path.joinpath("output/for/this/test")
    output_path.mkdir(parents=True)

    rel_path = output_path.relative_to(tmp_path)

    expected_outputs = []

    for directory in rel_path.parents:
        searchable_file = tmp_path / directory / "test.enc"
        searchable_file.touch()
        expected_outputs.append(searchable_file)

    assert sorted(find_enc_files([tmp_path])) == sorted(expected_outputs)


@pytest.mark.parametrize(
    ("existing", "out_path", "expected_result", "expected_msg"),
    [
        pytest.param(None, None, False, None, id="out_path_not_exists"),
        pytest.param("test.tar.gz", None, True, "Output file", id="out_path_exists"),
        pytest.param(None, None, False, None, id="decompressed_not_exists"),
        pytest.param("test.tar", None, True, "Decompressed file", id="decompressed_exists"),
        pytest.param(None, "test.tar", False, None, id="custom_filename_not_exists"),
        pytest.param("test.tar", "test.tar", True, None, id="custom_filename_exists"),
    ],
)
def test_check_existing(
    tmp_path: Path, out_path: str, existing: str | None, expected_result: bool, expected_msg: str | None
) -> None:
    queue = Queue()
    out_path = tmp_path / (out_path or "test.tar.gz")
    in_path = tmp_path / "test.tar.gz.enc"
    in_path.touch()

    if existing:
        existing = tmp_path / existing
        existing.touch()

    result = check_existing(in_path, out_path, queue)

    assert result == expected_result

    if expected_msg:
        _, msg_result = queue.get(timeout=1)
        assert expected_msg in msg_result
